export const colorLegend = (selection, props) => {
  const {                      
    colorScale,                
    circleRadius,
    spacing,                   
    textOffset,
    backgroundRectWidth,
    onClick,
    selectedCountry
  } = props;      

  const backgroundRect = selection.selectAll('rect')
    .data([null]);             
  const n = colorScale.domain().length; 
  backgroundRect.enter().append('rect')
    .merge(backgroundRect)
      .attr('x', -circleRadius * 2)   
      .attr('y', -circleRadius * 2+305)   
      .attr('rx', circleRadius * 2)   
      .attr('width', backgroundRectWidth)
      .attr('height', spacing * n + circleRadius * 2) 
      .attr('fill', 'yellow')
      .attr('opacity', 0.5);

  const groups = selection.selectAll('.legend')
    .data(colorScale.domain());
  
  const groupsEnter = groups
    .enter().append('g')
      .attr('class', 'legend');
  
  groupsEnter
    .merge(groups)
      .attr('transform', (d, i) => `translate(10, ${305+i * spacing})`)
      .attr('opacity', d =>
        (!selectedCountry || d === selectedCountry) ? 1 : 0.2)
      .on('click', d => onClick(
        d === selectedCountry ? null : d));
      
  groups.exit().remove();
  
  groupsEnter.append('circle')
    .merge(groups.select('circle')) 
      .attr('r', circleRadius)
      .attr('fill', colorScale);      
  
  groupsEnter.append('text')
    .merge(groups.select('text'))   
      .text(d => d)
      .attr('dy', '0.32em')
      .attr('x', textOffset);
}